@@ -24,5 +24,8 @@ flaspi.post_api("/greeting", greeting_func, app = app)
 # run server
 app.run(host = "0.0.0.0", port = "80", debug = False)
 
-# to call api
+# to call api (method 1)
+flaspi.call_post_api("http://localhost:80/greeting", {"name": "Hoge"})	# call post api
+
+# to call api (method 2)
 # curl http://localhost:80/greeting -X POST -H "Content-Type: application/json" --data '{"name": "Hoge"}'
